# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Registry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'url': 'str',
        'name': 'str',
        'credential': 'RegistryCredential',
        'type': 'str',
        'insecure': 'bool',
        'description': 'str',
        'status': 'str',
        'creation_time': 'datetime',
        'update_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'url': 'url',
        'name': 'name',
        'credential': 'credential',
        'type': 'type',
        'insecure': 'insecure',
        'description': 'description',
        'status': 'status',
        'creation_time': 'creation_time',
        'update_time': 'update_time'
    }

    def __init__(self, id=None, url=None, name=None, credential=None, type=None, insecure=None, description=None, status=None, creation_time=None, update_time=None, _configuration=None):  # noqa: E501
        """Registry - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._url = None
        self._name = None
        self._credential = None
        self._type = None
        self._insecure = None
        self._description = None
        self._status = None
        self._creation_time = None
        self._update_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if url is not None:
            self.url = url
        if name is not None:
            self.name = name
        if credential is not None:
            self.credential = credential
        if type is not None:
            self.type = type
        if insecure is not None:
            self.insecure = insecure
        if description is not None:
            self.description = description
        if status is not None:
            self.status = status
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time

    @property
    def id(self):
        """Gets the id of this Registry.  # noqa: E501

        The registry ID.  # noqa: E501

        :return: The id of this Registry.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Registry.

        The registry ID.  # noqa: E501

        :param id: The id of this Registry.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def url(self):
        """Gets the url of this Registry.  # noqa: E501

        The registry URL string.  # noqa: E501

        :return: The url of this Registry.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Registry.

        The registry URL string.  # noqa: E501

        :param url: The url of this Registry.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def name(self):
        """Gets the name of this Registry.  # noqa: E501

        The registry name.  # noqa: E501

        :return: The name of this Registry.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Registry.

        The registry name.  # noqa: E501

        :param name: The name of this Registry.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def credential(self):
        """Gets the credential of this Registry.  # noqa: E501


        :return: The credential of this Registry.  # noqa: E501
        :rtype: RegistryCredential
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """Sets the credential of this Registry.


        :param credential: The credential of this Registry.  # noqa: E501
        :type: RegistryCredential
        """

        self._credential = credential

    @property
    def type(self):
        """Gets the type of this Registry.  # noqa: E501

        Type of the registry, e.g. 'harbor'.  # noqa: E501

        :return: The type of this Registry.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Registry.

        Type of the registry, e.g. 'harbor'.  # noqa: E501

        :param type: The type of this Registry.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def insecure(self):
        """Gets the insecure of this Registry.  # noqa: E501

        Whether or not the certificate will be verified when Harbor tries to access the server.  # noqa: E501

        :return: The insecure of this Registry.  # noqa: E501
        :rtype: bool
        """
        return self._insecure

    @insecure.setter
    def insecure(self, insecure):
        """Sets the insecure of this Registry.

        Whether or not the certificate will be verified when Harbor tries to access the server.  # noqa: E501

        :param insecure: The insecure of this Registry.  # noqa: E501
        :type: bool
        """

        self._insecure = insecure

    @property
    def description(self):
        """Gets the description of this Registry.  # noqa: E501

        Description of the registry.  # noqa: E501

        :return: The description of this Registry.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Registry.

        Description of the registry.  # noqa: E501

        :param description: The description of this Registry.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status(self):
        """Gets the status of this Registry.  # noqa: E501

        Health status of the registry.  # noqa: E501

        :return: The status of this Registry.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Registry.

        Health status of the registry.  # noqa: E501

        :param status: The status of this Registry.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def creation_time(self):
        """Gets the creation_time of this Registry.  # noqa: E501

        The create time of the policy.  # noqa: E501

        :return: The creation_time of this Registry.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this Registry.

        The create time of the policy.  # noqa: E501

        :param creation_time: The creation_time of this Registry.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this Registry.  # noqa: E501

        The update time of the policy.  # noqa: E501

        :return: The update_time of this Registry.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Registry.

        The update time of the policy.  # noqa: E501

        :param update_time: The update_time of this Registry.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Registry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Registry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Registry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Project(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_id': 'int',
        'owner_id': 'int',
        'name': 'str',
        'registry_id': 'int',
        'creation_time': 'datetime',
        'update_time': 'datetime',
        'deleted': 'bool',
        'owner_name': 'str',
        'togglable': 'bool',
        'current_user_role_id': 'int',
        'current_user_role_ids': 'list[int]',
        'repo_count': 'int',
        'chart_count': 'int',
        'metadata': 'ProjectMetadata',
        'cve_allowlist': 'CVEAllowlist'
    }

    attribute_map = {
        'project_id': 'project_id',
        'owner_id': 'owner_id',
        'name': 'name',
        'registry_id': 'registry_id',
        'creation_time': 'creation_time',
        'update_time': 'update_time',
        'deleted': 'deleted',
        'owner_name': 'owner_name',
        'togglable': 'togglable',
        'current_user_role_id': 'current_user_role_id',
        'current_user_role_ids': 'current_user_role_ids',
        'repo_count': 'repo_count',
        'chart_count': 'chart_count',
        'metadata': 'metadata',
        'cve_allowlist': 'cve_allowlist'
    }

    def __init__(self, project_id=None, owner_id=None, name=None, registry_id=None, creation_time=None, update_time=None, deleted=None, owner_name=None, togglable=None, current_user_role_id=None, current_user_role_ids=None, repo_count=None, chart_count=None, metadata=None, cve_allowlist=None, _configuration=None):  # noqa: E501
        """Project - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._project_id = None
        self._owner_id = None
        self._name = None
        self._registry_id = None
        self._creation_time = None
        self._update_time = None
        self._deleted = None
        self._owner_name = None
        self._togglable = None
        self._current_user_role_id = None
        self._current_user_role_ids = None
        self._repo_count = None
        self._chart_count = None
        self._metadata = None
        self._cve_allowlist = None
        self.discriminator = None

        if project_id is not None:
            self.project_id = project_id
        if owner_id is not None:
            self.owner_id = owner_id
        if name is not None:
            self.name = name
        if registry_id is not None:
            self.registry_id = registry_id
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time
        if deleted is not None:
            self.deleted = deleted
        if owner_name is not None:
            self.owner_name = owner_name
        if togglable is not None:
            self.togglable = togglable
        if current_user_role_id is not None:
            self.current_user_role_id = current_user_role_id
        if current_user_role_ids is not None:
            self.current_user_role_ids = current_user_role_ids
        if repo_count is not None:
            self.repo_count = repo_count
        if chart_count is not None:
            self.chart_count = chart_count
        if metadata is not None:
            self.metadata = metadata
        if cve_allowlist is not None:
            self.cve_allowlist = cve_allowlist

    @property
    def project_id(self):
        """Gets the project_id of this Project.  # noqa: E501

        Project ID  # noqa: E501

        :return: The project_id of this Project.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this Project.

        Project ID  # noqa: E501

        :param project_id: The project_id of this Project.  # noqa: E501
        :type: int
        """

        self._project_id = project_id

    @property
    def owner_id(self):
        """Gets the owner_id of this Project.  # noqa: E501

        The owner ID of the project always means the creator of the project.  # noqa: E501

        :return: The owner_id of this Project.  # noqa: E501
        :rtype: int
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Project.

        The owner ID of the project always means the creator of the project.  # noqa: E501

        :param owner_id: The owner_id of this Project.  # noqa: E501
        :type: int
        """

        self._owner_id = owner_id

    @property
    def name(self):
        """Gets the name of this Project.  # noqa: E501

        The name of the project.  # noqa: E501

        :return: The name of this Project.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Project.

        The name of the project.  # noqa: E501

        :param name: The name of this Project.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def registry_id(self):
        """Gets the registry_id of this Project.  # noqa: E501

        The ID of referenced registry when the project is a proxy cache project.  # noqa: E501

        :return: The registry_id of this Project.  # noqa: E501
        :rtype: int
        """
        return self._registry_id

    @registry_id.setter
    def registry_id(self, registry_id):
        """Sets the registry_id of this Project.

        The ID of referenced registry when the project is a proxy cache project.  # noqa: E501

        :param registry_id: The registry_id of this Project.  # noqa: E501
        :type: int
        """

        self._registry_id = registry_id

    @property
    def creation_time(self):
        """Gets the creation_time of this Project.  # noqa: E501

        The creation time of the project.  # noqa: E501

        :return: The creation_time of this Project.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this Project.

        The creation time of the project.  # noqa: E501

        :param creation_time: The creation_time of this Project.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this Project.  # noqa: E501

        The update time of the project.  # noqa: E501

        :return: The update_time of this Project.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Project.

        The update time of the project.  # noqa: E501

        :param update_time: The update_time of this Project.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    @property
    def deleted(self):
        """Gets the deleted of this Project.  # noqa: E501

        A deletion mark of the project.  # noqa: E501

        :return: The deleted of this Project.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this Project.

        A deletion mark of the project.  # noqa: E501

        :param deleted: The deleted of this Project.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def owner_name(self):
        """Gets the owner_name of this Project.  # noqa: E501

        The owner name of the project.  # noqa: E501

        :return: The owner_name of this Project.  # noqa: E501
        :rtype: str
        """
        return self._owner_name

    @owner_name.setter
    def owner_name(self, owner_name):
        """Sets the owner_name of this Project.

        The owner name of the project.  # noqa: E501

        :param owner_name: The owner_name of this Project.  # noqa: E501
        :type: str
        """

        self._owner_name = owner_name

    @property
    def togglable(self):
        """Gets the togglable of this Project.  # noqa: E501

        Correspond to the UI about whether the project's publicity is  updatable (for UI)  # noqa: E501

        :return: The togglable of this Project.  # noqa: E501
        :rtype: bool
        """
        return self._togglable

    @togglable.setter
    def togglable(self, togglable):
        """Sets the togglable of this Project.

        Correspond to the UI about whether the project's publicity is  updatable (for UI)  # noqa: E501

        :param togglable: The togglable of this Project.  # noqa: E501
        :type: bool
        """

        self._togglable = togglable

    @property
    def current_user_role_id(self):
        """Gets the current_user_role_id of this Project.  # noqa: E501

        The role ID with highest permission of the current user who triggered the API (for UI).  This attribute is deprecated and will be removed in future versions.  # noqa: E501

        :return: The current_user_role_id of this Project.  # noqa: E501
        :rtype: int
        """
        return self._current_user_role_id

    @current_user_role_id.setter
    def current_user_role_id(self, current_user_role_id):
        """Sets the current_user_role_id of this Project.

        The role ID with highest permission of the current user who triggered the API (for UI).  This attribute is deprecated and will be removed in future versions.  # noqa: E501

        :param current_user_role_id: The current_user_role_id of this Project.  # noqa: E501
        :type: int
        """

        self._current_user_role_id = current_user_role_id

    @property
    def current_user_role_ids(self):
        """Gets the current_user_role_ids of this Project.  # noqa: E501

        The list of role ID of the current user who triggered the API (for UI)  # noqa: E501

        :return: The current_user_role_ids of this Project.  # noqa: E501
        :rtype: list[int]
        """
        return self._current_user_role_ids

    @current_user_role_ids.setter
    def current_user_role_ids(self, current_user_role_ids):
        """Sets the current_user_role_ids of this Project.

        The list of role ID of the current user who triggered the API (for UI)  # noqa: E501

        :param current_user_role_ids: The current_user_role_ids of this Project.  # noqa: E501
        :type: list[int]
        """

        self._current_user_role_ids = current_user_role_ids

    @property
    def repo_count(self):
        """Gets the repo_count of this Project.  # noqa: E501

        The number of the repositories under this project.  # noqa: E501

        :return: The repo_count of this Project.  # noqa: E501
        :rtype: int
        """
        return self._repo_count

    @repo_count.setter
    def repo_count(self, repo_count):
        """Sets the repo_count of this Project.

        The number of the repositories under this project.  # noqa: E501

        :param repo_count: The repo_count of this Project.  # noqa: E501
        :type: int
        """

        self._repo_count = repo_count

    @property
    def chart_count(self):
        """Gets the chart_count of this Project.  # noqa: E501

        The total number of charts under this project.  # noqa: E501

        :return: The chart_count of this Project.  # noqa: E501
        :rtype: int
        """
        return self._chart_count

    @chart_count.setter
    def chart_count(self, chart_count):
        """Sets the chart_count of this Project.

        The total number of charts under this project.  # noqa: E501

        :param chart_count: The chart_count of this Project.  # noqa: E501
        :type: int
        """

        self._chart_count = chart_count

    @property
    def metadata(self):
        """Gets the metadata of this Project.  # noqa: E501

        The metadata of the project.  # noqa: E501

        :return: The metadata of this Project.  # noqa: E501
        :rtype: ProjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Project.

        The metadata of the project.  # noqa: E501

        :param metadata: The metadata of this Project.  # noqa: E501
        :type: ProjectMetadata
        """

        self._metadata = metadata

    @property
    def cve_allowlist(self):
        """Gets the cve_allowlist of this Project.  # noqa: E501

        The CVE allowlist of this project.  # noqa: E501

        :return: The cve_allowlist of this Project.  # noqa: E501
        :rtype: CVEAllowlist
        """
        return self._cve_allowlist

    @cve_allowlist.setter
    def cve_allowlist(self, cve_allowlist):
        """Sets the cve_allowlist of this Project.

        The CVE allowlist of this project.  # noqa: E501

        :param cve_allowlist: The cve_allowlist of this Project.  # noqa: E501
        :type: CVEAllowlist
        """

        self._cve_allowlist = cve_allowlist

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Project, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Project):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Project):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RegistryInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'description': 'str',
        'supported_resource_filters': 'list[FilterStyle]',
        'supported_triggers': 'list[str]',
        'supported_copy_by_chunk': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'description': 'description',
        'supported_resource_filters': 'supported_resource_filters',
        'supported_triggers': 'supported_triggers',
        'supported_copy_by_chunk': 'supported_copy_by_chunk'
    }

    def __init__(self, type=None, description=None, supported_resource_filters=None, supported_triggers=None, supported_copy_by_chunk=None, _configuration=None):  # noqa: E501
        """RegistryInfo - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type = None
        self._description = None
        self._supported_resource_filters = None
        self._supported_triggers = None
        self._supported_copy_by_chunk = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if supported_resource_filters is not None:
            self.supported_resource_filters = supported_resource_filters
        if supported_triggers is not None:
            self.supported_triggers = supported_triggers
        if supported_copy_by_chunk is not None:
            self.supported_copy_by_chunk = supported_copy_by_chunk

    @property
    def type(self):
        """Gets the type of this RegistryInfo.  # noqa: E501

        The registry type  # noqa: E501

        :return: The type of this RegistryInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RegistryInfo.

        The registry type  # noqa: E501

        :param type: The type of this RegistryInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this RegistryInfo.  # noqa: E501

        The description  # noqa: E501

        :return: The description of this RegistryInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RegistryInfo.

        The description  # noqa: E501

        :param description: The description of this RegistryInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def supported_resource_filters(self):
        """Gets the supported_resource_filters of this RegistryInfo.  # noqa: E501

        The filters that the registry supports  # noqa: E501

        :return: The supported_resource_filters of this RegistryInfo.  # noqa: E501
        :rtype: list[FilterStyle]
        """
        return self._supported_resource_filters

    @supported_resource_filters.setter
    def supported_resource_filters(self, supported_resource_filters):
        """Sets the supported_resource_filters of this RegistryInfo.

        The filters that the registry supports  # noqa: E501

        :param supported_resource_filters: The supported_resource_filters of this RegistryInfo.  # noqa: E501
        :type: list[FilterStyle]
        """

        self._supported_resource_filters = supported_resource_filters

    @property
    def supported_triggers(self):
        """Gets the supported_triggers of this RegistryInfo.  # noqa: E501

        The triggers that the registry supports  # noqa: E501

        :return: The supported_triggers of this RegistryInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_triggers

    @supported_triggers.setter
    def supported_triggers(self, supported_triggers):
        """Sets the supported_triggers of this RegistryInfo.

        The triggers that the registry supports  # noqa: E501

        :param supported_triggers: The supported_triggers of this RegistryInfo.  # noqa: E501
        :type: list[str]
        """

        self._supported_triggers = supported_triggers

    @property
    def supported_copy_by_chunk(self):
        """Gets the supported_copy_by_chunk of this RegistryInfo.  # noqa: E501

        The registry whether support copy by chunk.  # noqa: E501

        :return: The supported_copy_by_chunk of this RegistryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supported_copy_by_chunk

    @supported_copy_by_chunk.setter
    def supported_copy_by_chunk(self, supported_copy_by_chunk):
        """Sets the supported_copy_by_chunk of this RegistryInfo.

        The registry whether support copy by chunk.  # noqa: E501

        :param supported_copy_by_chunk: The supported_copy_by_chunk of this RegistryInfo.  # noqa: E501
        :type: bool
        """

        self._supported_copy_by_chunk = supported_copy_by_chunk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RegistryInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RobotCreateV1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'expires_at': 'int',
        'access': 'list[Access]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'expires_at': 'expires_at',
        'access': 'access'
    }

    def __init__(self, name=None, description=None, expires_at=None, access=None, _configuration=None):  # noqa: E501
        """RobotCreateV1 - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._description = None
        self._expires_at = None
        self._access = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if expires_at is not None:
            self.expires_at = expires_at
        if access is not None:
            self.access = access

    @property
    def name(self):
        """Gets the name of this RobotCreateV1.  # noqa: E501

        The name of robot account  # noqa: E501

        :return: The name of this RobotCreateV1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RobotCreateV1.

        The name of robot account  # noqa: E501

        :param name: The name of this RobotCreateV1.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this RobotCreateV1.  # noqa: E501

        The description of robot account  # noqa: E501

        :return: The description of this RobotCreateV1.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RobotCreateV1.

        The description of robot account  # noqa: E501

        :param description: The description of this RobotCreateV1.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expires_at(self):
        """Gets the expires_at of this RobotCreateV1.  # noqa: E501

        The expiration time on or after which the JWT MUST NOT be accepted for processing.  # noqa: E501

        :return: The expires_at of this RobotCreateV1.  # noqa: E501
        :rtype: int
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this RobotCreateV1.

        The expiration time on or after which the JWT MUST NOT be accepted for processing.  # noqa: E501

        :param expires_at: The expires_at of this RobotCreateV1.  # noqa: E501
        :type: int
        """

        self._expires_at = expires_at

    @property
    def access(self):
        """Gets the access of this RobotCreateV1.  # noqa: E501

        The permission of robot account  # noqa: E501

        :return: The access of this RobotCreateV1.  # noqa: E501
        :rtype: list[Access]
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this RobotCreateV1.

        The permission of robot account  # noqa: E501

        :param access: The access of this RobotCreateV1.  # noqa: E501
        :type: list[Access]
        """

        self._access = access

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RobotCreateV1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RobotCreateV1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RobotCreateV1):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class UserCreationReq(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'realname': 'str',
        'comment': 'str',
        'password': 'str',
        'username': 'str'
    }

    attribute_map = {
        'email': 'email',
        'realname': 'realname',
        'comment': 'comment',
        'password': 'password',
        'username': 'username'
    }

    def __init__(self, email=None, realname=None, comment=None, password=None, username=None, _configuration=None):  # noqa: E501
        """UserCreationReq - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._realname = None
        self._comment = None
        self._password = None
        self._username = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if realname is not None:
            self.realname = realname
        if comment is not None:
            self.comment = comment
        if password is not None:
            self.password = password
        if username is not None:
            self.username = username

    @property
    def email(self):
        """Gets the email of this UserCreationReq.  # noqa: E501


        :return: The email of this UserCreationReq.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserCreationReq.


        :param email: The email of this UserCreationReq.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                email is not None and len(email) > 255):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `255`")  # noqa: E501

        self._email = email

    @property
    def realname(self):
        """Gets the realname of this UserCreationReq.  # noqa: E501


        :return: The realname of this UserCreationReq.  # noqa: E501
        :rtype: str
        """
        return self._realname

    @realname.setter
    def realname(self, realname):
        """Sets the realname of this UserCreationReq.


        :param realname: The realname of this UserCreationReq.  # noqa: E501
        :type: str
        """

        self._realname = realname

    @property
    def comment(self):
        """Gets the comment of this UserCreationReq.  # noqa: E501


        :return: The comment of this UserCreationReq.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UserCreationReq.


        :param comment: The comment of this UserCreationReq.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def password(self):
        """Gets the password of this UserCreationReq.  # noqa: E501


        :return: The password of this UserCreationReq.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UserCreationReq.


        :param password: The password of this UserCreationReq.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def username(self):
        """Gets the username of this UserCreationReq.  # noqa: E501


        :return: The username of this UserCreationReq.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UserCreationReq.


        :param username: The username of this UserCreationReq.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                username is not None and len(username) > 255):
            raise ValueError("Invalid value for `username`, length must be less than or equal to `255`")  # noqa: E501

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserCreationReq, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserCreationReq):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserCreationReq):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class AuthproxySetting(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'endpoint': 'str',
        'tokenreivew_endpoint': 'str',
        'skip_search': 'bool',
        'verify_cert': 'bool',
        'server_certificate': 'str'
    }

    attribute_map = {
        'endpoint': 'endpoint',
        'tokenreivew_endpoint': 'tokenreivew_endpoint',
        'skip_search': 'skip_search',
        'verify_cert': 'verify_cert',
        'server_certificate': 'server_certificate'
    }

    def __init__(self, endpoint=None, tokenreivew_endpoint=None, skip_search=None, verify_cert=None, server_certificate=None, _configuration=None):  # noqa: E501
        """AuthproxySetting - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._endpoint = None
        self._tokenreivew_endpoint = None
        self._skip_search = None
        self._verify_cert = None
        self._server_certificate = None
        self.discriminator = None

        if endpoint is not None:
            self.endpoint = endpoint
        if tokenreivew_endpoint is not None:
            self.tokenreivew_endpoint = tokenreivew_endpoint
        if skip_search is not None:
            self.skip_search = skip_search
        if verify_cert is not None:
            self.verify_cert = verify_cert
        if server_certificate is not None:
            self.server_certificate = server_certificate

    @property
    def endpoint(self):
        """Gets the endpoint of this AuthproxySetting.  # noqa: E501

        The fully qualified URI of login endpoint of authproxy, such as 'https://192.168.1.2:8443/login'  # noqa: E501

        :return: The endpoint of this AuthproxySetting.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this AuthproxySetting.

        The fully qualified URI of login endpoint of authproxy, such as 'https://192.168.1.2:8443/login'  # noqa: E501

        :param endpoint: The endpoint of this AuthproxySetting.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def tokenreivew_endpoint(self):
        """Gets the tokenreivew_endpoint of this AuthproxySetting.  # noqa: E501

        The fully qualified URI of token review endpoint of authproxy, such as 'https://192.168.1.2:8443/tokenreview'  # noqa: E501

        :return: The tokenreivew_endpoint of this AuthproxySetting.  # noqa: E501
        :rtype: str
        """
        return self._tokenreivew_endpoint

    @tokenreivew_endpoint.setter
    def tokenreivew_endpoint(self, tokenreivew_endpoint):
        """Sets the tokenreivew_endpoint of this AuthproxySetting.

        The fully qualified URI of token review endpoint of authproxy, such as 'https://192.168.1.2:8443/tokenreview'  # noqa: E501

        :param tokenreivew_endpoint: The tokenreivew_endpoint of this AuthproxySetting.  # noqa: E501
        :type: str
        """

        self._tokenreivew_endpoint = tokenreivew_endpoint

    @property
    def skip_search(self):
        """Gets the skip_search of this AuthproxySetting.  # noqa: E501

        The flag to determine whether Harbor can skip search the user/group when adding him as a member.  # noqa: E501

        :return: The skip_search of this AuthproxySetting.  # noqa: E501
        :rtype: bool
        """
        return self._skip_search

    @skip_search.setter
    def skip_search(self, skip_search):
        """Sets the skip_search of this AuthproxySetting.

        The flag to determine whether Harbor can skip search the user/group when adding him as a member.  # noqa: E501

        :param skip_search: The skip_search of this AuthproxySetting.  # noqa: E501
        :type: bool
        """

        self._skip_search = skip_search

    @property
    def verify_cert(self):
        """Gets the verify_cert of this AuthproxySetting.  # noqa: E501

        The flag to determine whether Harbor should verify the certificate when connecting to the auth proxy.  # noqa: E501

        :return: The verify_cert of this AuthproxySetting.  # noqa: E501
        :rtype: bool
        """
        return self._verify_cert

    @verify_cert.setter
    def verify_cert(self, verify_cert):
        """Sets the verify_cert of this AuthproxySetting.

        The flag to determine whether Harbor should verify the certificate when connecting to the auth proxy.  # noqa: E501

        :param verify_cert: The verify_cert of this AuthproxySetting.  # noqa: E501
        :type: bool
        """

        self._verify_cert = verify_cert

    @property
    def server_certificate(self):
        """Gets the server_certificate of this AuthproxySetting.  # noqa: E501

        The certificate to be pinned when connecting auth proxy.  # noqa: E501

        :return: The server_certificate of this AuthproxySetting.  # noqa: E501
        :rtype: str
        """
        return self._server_certificate

    @server_certificate.setter
    def server_certificate(self, server_certificate):
        """Sets the server_certificate of this AuthproxySetting.

        The certificate to be pinned when connecting auth proxy.  # noqa: E501

        :param server_certificate: The server_certificate of this AuthproxySetting.  # noqa: E501
        :type: str
        """

        self._server_certificate = server_certificate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuthproxySetting, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthproxySetting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthproxySetting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class LdapConf(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ldap_url': 'str',
        'ldap_search_dn': 'str',
        'ldap_search_password': 'str',
        'ldap_base_dn': 'str',
        'ldap_filter': 'str',
        'ldap_uid': 'str',
        'ldap_scope': 'int',
        'ldap_connection_timeout': 'int',
        'ldap_verify_cert': 'bool'
    }

    attribute_map = {
        'ldap_url': 'ldap_url',
        'ldap_search_dn': 'ldap_search_dn',
        'ldap_search_password': 'ldap_search_password',
        'ldap_base_dn': 'ldap_base_dn',
        'ldap_filter': 'ldap_filter',
        'ldap_uid': 'ldap_uid',
        'ldap_scope': 'ldap_scope',
        'ldap_connection_timeout': 'ldap_connection_timeout',
        'ldap_verify_cert': 'ldap_verify_cert'
    }

    def __init__(self, ldap_url=None, ldap_search_dn=None, ldap_search_password=None, ldap_base_dn=None, ldap_filter=None, ldap_uid=None, ldap_scope=None, ldap_connection_timeout=None, ldap_verify_cert=None, _configuration=None):  # noqa: E501
        """LdapConf - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ldap_url = None
        self._ldap_search_dn = None
        self._ldap_search_password = None
        self._ldap_base_dn = None
        self._ldap_filter = None
        self._ldap_uid = None
        self._ldap_scope = None
        self._ldap_connection_timeout = None
        self._ldap_verify_cert = None
        self.discriminator = None

        if ldap_url is not None:
            self.ldap_url = ldap_url
        if ldap_search_dn is not None:
            self.ldap_search_dn = ldap_search_dn
        if ldap_search_password is not None:
            self.ldap_search_password = ldap_search_password
        if ldap_base_dn is not None:
            self.ldap_base_dn = ldap_base_dn
        if ldap_filter is not None:
            self.ldap_filter = ldap_filter
        if ldap_uid is not None:
            self.ldap_uid = ldap_uid
        if ldap_scope is not None:
            self.ldap_scope = ldap_scope
        if ldap_connection_timeout is not None:
            self.ldap_connection_timeout = ldap_connection_timeout
        if ldap_verify_cert is not None:
            self.ldap_verify_cert = ldap_verify_cert

    @property
    def ldap_url(self):
        """Gets the ldap_url of this LdapConf.  # noqa: E501

        The url of ldap service.  # noqa: E501

        :return: The ldap_url of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_url

    @ldap_url.setter
    def ldap_url(self, ldap_url):
        """Sets the ldap_url of this LdapConf.

        The url of ldap service.  # noqa: E501

        :param ldap_url: The ldap_url of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_url = ldap_url

    @property
    def ldap_search_dn(self):
        """Gets the ldap_search_dn of this LdapConf.  # noqa: E501

        The search dn of ldap service.  # noqa: E501

        :return: The ldap_search_dn of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_search_dn

    @ldap_search_dn.setter
    def ldap_search_dn(self, ldap_search_dn):
        """Sets the ldap_search_dn of this LdapConf.

        The search dn of ldap service.  # noqa: E501

        :param ldap_search_dn: The ldap_search_dn of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_search_dn = ldap_search_dn

    @property
    def ldap_search_password(self):
        """Gets the ldap_search_password of this LdapConf.  # noqa: E501

        The search password of ldap service.  # noqa: E501

        :return: The ldap_search_password of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_search_password

    @ldap_search_password.setter
    def ldap_search_password(self, ldap_search_password):
        """Sets the ldap_search_password of this LdapConf.

        The search password of ldap service.  # noqa: E501

        :param ldap_search_password: The ldap_search_password of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_search_password = ldap_search_password

    @property
    def ldap_base_dn(self):
        """Gets the ldap_base_dn of this LdapConf.  # noqa: E501

        The base dn of ldap service.  # noqa: E501

        :return: The ldap_base_dn of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_base_dn

    @ldap_base_dn.setter
    def ldap_base_dn(self, ldap_base_dn):
        """Sets the ldap_base_dn of this LdapConf.

        The base dn of ldap service.  # noqa: E501

        :param ldap_base_dn: The ldap_base_dn of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_base_dn = ldap_base_dn

    @property
    def ldap_filter(self):
        """Gets the ldap_filter of this LdapConf.  # noqa: E501

        The serach filter of ldap service.  # noqa: E501

        :return: The ldap_filter of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_filter

    @ldap_filter.setter
    def ldap_filter(self, ldap_filter):
        """Sets the ldap_filter of this LdapConf.

        The serach filter of ldap service.  # noqa: E501

        :param ldap_filter: The ldap_filter of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_filter = ldap_filter

    @property
    def ldap_uid(self):
        """Gets the ldap_uid of this LdapConf.  # noqa: E501

        The serach uid from ldap service attributes.  # noqa: E501

        :return: The ldap_uid of this LdapConf.  # noqa: E501
        :rtype: str
        """
        return self._ldap_uid

    @ldap_uid.setter
    def ldap_uid(self, ldap_uid):
        """Sets the ldap_uid of this LdapConf.

        The serach uid from ldap service attributes.  # noqa: E501

        :param ldap_uid: The ldap_uid of this LdapConf.  # noqa: E501
        :type: str
        """

        self._ldap_uid = ldap_uid

    @property
    def ldap_scope(self):
        """Gets the ldap_scope of this LdapConf.  # noqa: E501

        The serach scope of ldap service.  # noqa: E501

        :return: The ldap_scope of this LdapConf.  # noqa: E501
        :rtype: int
        """
        return self._ldap_scope

    @ldap_scope.setter
    def ldap_scope(self, ldap_scope):
        """Sets the ldap_scope of this LdapConf.

        The serach scope of ldap service.  # noqa: E501

        :param ldap_scope: The ldap_scope of this LdapConf.  # noqa: E501
        :type: int
        """

        self._ldap_scope = ldap_scope

    @property
    def ldap_connection_timeout(self):
        """Gets the ldap_connection_timeout of this LdapConf.  # noqa: E501

        The connect timeout of ldap service(second).  # noqa: E501

        :return: The ldap_connection_timeout of this LdapConf.  # noqa: E501
        :rtype: int
        """
        return self._ldap_connection_timeout

    @ldap_connection_timeout.setter
    def ldap_connection_timeout(self, ldap_connection_timeout):
        """Sets the ldap_connection_timeout of this LdapConf.

        The connect timeout of ldap service(second).  # noqa: E501

        :param ldap_connection_timeout: The ldap_connection_timeout of this LdapConf.  # noqa: E501
        :type: int
        """

        self._ldap_connection_timeout = ldap_connection_timeout

    @property
    def ldap_verify_cert(self):
        """Gets the ldap_verify_cert of this LdapConf.  # noqa: E501

        Verify Ldap server certificate.  # noqa: E501

        :return: The ldap_verify_cert of this LdapConf.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_verify_cert

    @ldap_verify_cert.setter
    def ldap_verify_cert(self, ldap_verify_cert):
        """Sets the ldap_verify_cert of this LdapConf.

        Verify Ldap server certificate.  # noqa: E501

        :param ldap_verify_cert: The ldap_verify_cert of this LdapConf.  # noqa: E501
        :type: bool
        """

        self._ldap_verify_cert = ldap_verify_cert

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LdapConf, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LdapConf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LdapConf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RegistryUpdate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'url': 'str',
        'credential_type': 'str',
        'access_key': 'str',
        'access_secret': 'str',
        'insecure': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'url': 'url',
        'credential_type': 'credential_type',
        'access_key': 'access_key',
        'access_secret': 'access_secret',
        'insecure': 'insecure'
    }

    def __init__(self, name=None, description=None, url=None, credential_type=None, access_key=None, access_secret=None, insecure=None, _configuration=None):  # noqa: E501
        """RegistryUpdate - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._description = None
        self._url = None
        self._credential_type = None
        self._access_key = None
        self._access_secret = None
        self._insecure = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if url is not None:
            self.url = url
        if credential_type is not None:
            self.credential_type = credential_type
        if access_key is not None:
            self.access_key = access_key
        if access_secret is not None:
            self.access_secret = access_secret
        if insecure is not None:
            self.insecure = insecure

    @property
    def name(self):
        """Gets the name of this RegistryUpdate.  # noqa: E501

        The registry name.  # noqa: E501

        :return: The name of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RegistryUpdate.

        The registry name.  # noqa: E501

        :param name: The name of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this RegistryUpdate.  # noqa: E501

        Description of the registry.  # noqa: E501

        :return: The description of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RegistryUpdate.

        Description of the registry.  # noqa: E501

        :param description: The description of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def url(self):
        """Gets the url of this RegistryUpdate.  # noqa: E501

        The registry URL.  # noqa: E501

        :return: The url of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this RegistryUpdate.

        The registry URL.  # noqa: E501

        :param url: The url of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def credential_type(self):
        """Gets the credential_type of this RegistryUpdate.  # noqa: E501

        Credential type of the registry, e.g. 'basic'.  # noqa: E501

        :return: The credential_type of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._credential_type

    @credential_type.setter
    def credential_type(self, credential_type):
        """Sets the credential_type of this RegistryUpdate.

        Credential type of the registry, e.g. 'basic'.  # noqa: E501

        :param credential_type: The credential_type of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._credential_type = credential_type

    @property
    def access_key(self):
        """Gets the access_key of this RegistryUpdate.  # noqa: E501

        The registry access key.  # noqa: E501

        :return: The access_key of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this RegistryUpdate.

        The registry access key.  # noqa: E501

        :param access_key: The access_key of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._access_key = access_key

    @property
    def access_secret(self):
        """Gets the access_secret of this RegistryUpdate.  # noqa: E501

        The registry access secret.  # noqa: E501

        :return: The access_secret of this RegistryUpdate.  # noqa: E501
        :rtype: str
        """
        return self._access_secret

    @access_secret.setter
    def access_secret(self, access_secret):
        """Sets the access_secret of this RegistryUpdate.

        The registry access secret.  # noqa: E501

        :param access_secret: The access_secret of this RegistryUpdate.  # noqa: E501
        :type: str
        """

        self._access_secret = access_secret

    @property
    def insecure(self):
        """Gets the insecure of this RegistryUpdate.  # noqa: E501

        Whether or not the certificate will be verified when Harbor tries to access the server.  # noqa: E501

        :return: The insecure of this RegistryUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._insecure

    @insecure.setter
    def insecure(self, insecure):
        """Sets the insecure of this RegistryUpdate.

        Whether or not the certificate will be verified when Harbor tries to access the server.  # noqa: E501

        :param insecure: The insecure of this RegistryUpdate.  # noqa: E501
        :type: bool
        """

        self._insecure = insecure

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RegistryUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class SearchApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def search(self, q, **kwargs):  # noqa: E501
        """Search for projects, repositories and helm charts  # noqa: E501

        The Search endpoint returns information about the projects, repositories and helm charts offered at public status or related to the current logged in user. The response includes the project, repository list and charts in a proper display order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(q, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: Search parameter for project and repository name. (required)
        :param str x_request_id: An unique ID for the request
        :return: Search
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_with_http_info(q, **kwargs)  # noqa: E501
        else:
            (data) = self.search_with_http_info(q, **kwargs)  # noqa: E501
            return data

    def search_with_http_info(self, q, **kwargs):  # noqa: E501
        """Search for projects, repositories and helm charts  # noqa: E501

        The Search endpoint returns information about the projects, repositories and helm charts offered at public status or related to the current logged in user. The response includes the project, repository list and charts in a proper display order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(q, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str q: Search parameter for project and repository name. (required)
        :param str x_request_id: An unique ID for the request
        :return: Search
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'q' is set
        if self.api_client.client_side_validation and ('q' not in params or
                                                       params['q'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `q` when calling `search`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `search`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Search',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProjectSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'repo_count': 'int',
        'chart_count': 'int',
        'project_admin_count': 'int',
        'maintainer_count': 'int',
        'developer_count': 'int',
        'guest_count': 'int',
        'limited_guest_count': 'int',
        'quota': 'ProjectSummaryQuota',
        'registry': 'Registry'
    }

    attribute_map = {
        'repo_count': 'repo_count',
        'chart_count': 'chart_count',
        'project_admin_count': 'project_admin_count',
        'maintainer_count': 'maintainer_count',
        'developer_count': 'developer_count',
        'guest_count': 'guest_count',
        'limited_guest_count': 'limited_guest_count',
        'quota': 'quota',
        'registry': 'registry'
    }

    def __init__(self, repo_count=None, chart_count=None, project_admin_count=None, maintainer_count=None, developer_count=None, guest_count=None, limited_guest_count=None, quota=None, registry=None, _configuration=None):  # noqa: E501
        """ProjectSummary - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._repo_count = None
        self._chart_count = None
        self._project_admin_count = None
        self._maintainer_count = None
        self._developer_count = None
        self._guest_count = None
        self._limited_guest_count = None
        self._quota = None
        self._registry = None
        self.discriminator = None

        if repo_count is not None:
            self.repo_count = repo_count
        if chart_count is not None:
            self.chart_count = chart_count
        if project_admin_count is not None:
            self.project_admin_count = project_admin_count
        if maintainer_count is not None:
            self.maintainer_count = maintainer_count
        if developer_count is not None:
            self.developer_count = developer_count
        if guest_count is not None:
            self.guest_count = guest_count
        if limited_guest_count is not None:
            self.limited_guest_count = limited_guest_count
        if quota is not None:
            self.quota = quota
        if registry is not None:
            self.registry = registry

    @property
    def repo_count(self):
        """Gets the repo_count of this ProjectSummary.  # noqa: E501

        The number of the repositories under this project.  # noqa: E501

        :return: The repo_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._repo_count

    @repo_count.setter
    def repo_count(self, repo_count):
        """Sets the repo_count of this ProjectSummary.

        The number of the repositories under this project.  # noqa: E501

        :param repo_count: The repo_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._repo_count = repo_count

    @property
    def chart_count(self):
        """Gets the chart_count of this ProjectSummary.  # noqa: E501

        The total number of charts under this project.  # noqa: E501

        :return: The chart_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._chart_count

    @chart_count.setter
    def chart_count(self, chart_count):
        """Sets the chart_count of this ProjectSummary.

        The total number of charts under this project.  # noqa: E501

        :param chart_count: The chart_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._chart_count = chart_count

    @property
    def project_admin_count(self):
        """Gets the project_admin_count of this ProjectSummary.  # noqa: E501

        The total number of project admin members.  # noqa: E501

        :return: The project_admin_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._project_admin_count

    @project_admin_count.setter
    def project_admin_count(self, project_admin_count):
        """Sets the project_admin_count of this ProjectSummary.

        The total number of project admin members.  # noqa: E501

        :param project_admin_count: The project_admin_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._project_admin_count = project_admin_count

    @property
    def maintainer_count(self):
        """Gets the maintainer_count of this ProjectSummary.  # noqa: E501

        The total number of maintainer members.  # noqa: E501

        :return: The maintainer_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._maintainer_count

    @maintainer_count.setter
    def maintainer_count(self, maintainer_count):
        """Sets the maintainer_count of this ProjectSummary.

        The total number of maintainer members.  # noqa: E501

        :param maintainer_count: The maintainer_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._maintainer_count = maintainer_count

    @property
    def developer_count(self):
        """Gets the developer_count of this ProjectSummary.  # noqa: E501

        The total number of developer members.  # noqa: E501

        :return: The developer_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._developer_count

    @developer_count.setter
    def developer_count(self, developer_count):
        """Sets the developer_count of this ProjectSummary.

        The total number of developer members.  # noqa: E501

        :param developer_count: The developer_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._developer_count = developer_count

    @property
    def guest_count(self):
        """Gets the guest_count of this ProjectSummary.  # noqa: E501

        The total number of guest members.  # noqa: E501

        :return: The guest_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._guest_count

    @guest_count.setter
    def guest_count(self, guest_count):
        """Sets the guest_count of this ProjectSummary.

        The total number of guest members.  # noqa: E501

        :param guest_count: The guest_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._guest_count = guest_count

    @property
    def limited_guest_count(self):
        """Gets the limited_guest_count of this ProjectSummary.  # noqa: E501

        The total number of limited guest members.  # noqa: E501

        :return: The limited_guest_count of this ProjectSummary.  # noqa: E501
        :rtype: int
        """
        return self._limited_guest_count

    @limited_guest_count.setter
    def limited_guest_count(self, limited_guest_count):
        """Sets the limited_guest_count of this ProjectSummary.

        The total number of limited guest members.  # noqa: E501

        :param limited_guest_count: The limited_guest_count of this ProjectSummary.  # noqa: E501
        :type: int
        """

        self._limited_guest_count = limited_guest_count

    @property
    def quota(self):
        """Gets the quota of this ProjectSummary.  # noqa: E501


        :return: The quota of this ProjectSummary.  # noqa: E501
        :rtype: ProjectSummaryQuota
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """Sets the quota of this ProjectSummary.


        :param quota: The quota of this ProjectSummary.  # noqa: E501
        :type: ProjectSummaryQuota
        """

        self._quota = quota

    @property
    def registry(self):
        """Gets the registry of this ProjectSummary.  # noqa: E501


        :return: The registry of this ProjectSummary.  # noqa: E501
        :rtype: Registry
        """
        return self._registry

    @registry.setter
    def registry(self, registry):
        """Sets the registry of this ProjectSummary.


        :param registry: The registry of this ProjectSummary.  # noqa: E501
        :type: Registry
        """

        self._registry = registry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Tag(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'repository_id': 'int',
        'artifact_id': 'int',
        'name': 'str',
        'push_time': 'datetime',
        'pull_time': 'datetime',
        'immutable': 'bool',
        'signed': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'repository_id': 'repository_id',
        'artifact_id': 'artifact_id',
        'name': 'name',
        'push_time': 'push_time',
        'pull_time': 'pull_time',
        'immutable': 'immutable',
        'signed': 'signed'
    }

    def __init__(self, id=None, repository_id=None, artifact_id=None, name=None, push_time=None, pull_time=None, immutable=None, signed=None, _configuration=None):  # noqa: E501
        """Tag - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._repository_id = None
        self._artifact_id = None
        self._name = None
        self._push_time = None
        self._pull_time = None
        self._immutable = None
        self._signed = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if repository_id is not None:
            self.repository_id = repository_id
        if artifact_id is not None:
            self.artifact_id = artifact_id
        if name is not None:
            self.name = name
        if push_time is not None:
            self.push_time = push_time
        if pull_time is not None:
            self.pull_time = pull_time
        if immutable is not None:
            self.immutable = immutable
        if signed is not None:
            self.signed = signed

    @property
    def id(self):
        """Gets the id of this Tag.  # noqa: E501

        The ID of the tag  # noqa: E501

        :return: The id of this Tag.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Tag.

        The ID of the tag  # noqa: E501

        :param id: The id of this Tag.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def repository_id(self):
        """Gets the repository_id of this Tag.  # noqa: E501

        The ID of the repository that the tag belongs to  # noqa: E501

        :return: The repository_id of this Tag.  # noqa: E501
        :rtype: int
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """Sets the repository_id of this Tag.

        The ID of the repository that the tag belongs to  # noqa: E501

        :param repository_id: The repository_id of this Tag.  # noqa: E501
        :type: int
        """

        self._repository_id = repository_id

    @property
    def artifact_id(self):
        """Gets the artifact_id of this Tag.  # noqa: E501

        The ID of the artifact that the tag attached to  # noqa: E501

        :return: The artifact_id of this Tag.  # noqa: E501
        :rtype: int
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id):
        """Sets the artifact_id of this Tag.

        The ID of the artifact that the tag attached to  # noqa: E501

        :param artifact_id: The artifact_id of this Tag.  # noqa: E501
        :type: int
        """

        self._artifact_id = artifact_id

    @property
    def name(self):
        """Gets the name of this Tag.  # noqa: E501

        The name of the tag  # noqa: E501

        :return: The name of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Tag.

        The name of the tag  # noqa: E501

        :param name: The name of this Tag.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def push_time(self):
        """Gets the push_time of this Tag.  # noqa: E501

        The push time of the tag  # noqa: E501

        :return: The push_time of this Tag.  # noqa: E501
        :rtype: datetime
        """
        return self._push_time

    @push_time.setter
    def push_time(self, push_time):
        """Sets the push_time of this Tag.

        The push time of the tag  # noqa: E501

        :param push_time: The push_time of this Tag.  # noqa: E501
        :type: datetime
        """

        self._push_time = push_time

    @property
    def pull_time(self):
        """Gets the pull_time of this Tag.  # noqa: E501

        The latest pull time of the tag  # noqa: E501

        :return: The pull_time of this Tag.  # noqa: E501
        :rtype: datetime
        """
        return self._pull_time

    @pull_time.setter
    def pull_time(self, pull_time):
        """Sets the pull_time of this Tag.

        The latest pull time of the tag  # noqa: E501

        :param pull_time: The pull_time of this Tag.  # noqa: E501
        :type: datetime
        """

        self._pull_time = pull_time

    @property
    def immutable(self):
        """Gets the immutable of this Tag.  # noqa: E501

        The immutable status of the tag  # noqa: E501

        :return: The immutable of this Tag.  # noqa: E501
        :rtype: bool
        """
        return self._immutable

    @immutable.setter
    def immutable(self, immutable):
        """Sets the immutable of this Tag.

        The immutable status of the tag  # noqa: E501

        :param immutable: The immutable of this Tag.  # noqa: E501
        :type: bool
        """

        self._immutable = immutable

    @property
    def signed(self):
        """Gets the signed of this Tag.  # noqa: E501

        The attribute indicates whether the tag is signed or not  # noqa: E501

        :return: The signed of this Tag.  # noqa: E501
        :rtype: bool
        """
        return self._signed

    @signed.setter
    def signed(self, signed):
        """Sets the signed of this Tag.

        The attribute indicates whether the tag is signed or not  # noqa: E501

        :param signed: The signed of this Tag.  # noqa: E501
        :type: bool
        """

        self._signed = signed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tag, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tag):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Tag):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Reference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parent_id': 'int',
        'child_id': 'int',
        'child_digest': 'str',
        'platform': 'Platform',
        'annotations': 'Annotations',
        'urls': 'list[str]'
    }

    attribute_map = {
        'parent_id': 'parent_id',
        'child_id': 'child_id',
        'child_digest': 'child_digest',
        'platform': 'platform',
        'annotations': 'annotations',
        'urls': 'urls'
    }

    def __init__(self, parent_id=None, child_id=None, child_digest=None, platform=None, annotations=None, urls=None, _configuration=None):  # noqa: E501
        """Reference - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._parent_id = None
        self._child_id = None
        self._child_digest = None
        self._platform = None
        self._annotations = None
        self._urls = None
        self.discriminator = None

        if parent_id is not None:
            self.parent_id = parent_id
        if child_id is not None:
            self.child_id = child_id
        if child_digest is not None:
            self.child_digest = child_digest
        if platform is not None:
            self.platform = platform
        if annotations is not None:
            self.annotations = annotations
        if urls is not None:
            self.urls = urls

    @property
    def parent_id(self):
        """Gets the parent_id of this Reference.  # noqa: E501

        The parent ID of the reference  # noqa: E501

        :return: The parent_id of this Reference.  # noqa: E501
        :rtype: int
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Reference.

        The parent ID of the reference  # noqa: E501

        :param parent_id: The parent_id of this Reference.  # noqa: E501
        :type: int
        """

        self._parent_id = parent_id

    @property
    def child_id(self):
        """Gets the child_id of this Reference.  # noqa: E501

        The child ID of the reference  # noqa: E501

        :return: The child_id of this Reference.  # noqa: E501
        :rtype: int
        """
        return self._child_id

    @child_id.setter
    def child_id(self, child_id):
        """Sets the child_id of this Reference.

        The child ID of the reference  # noqa: E501

        :param child_id: The child_id of this Reference.  # noqa: E501
        :type: int
        """

        self._child_id = child_id

    @property
    def child_digest(self):
        """Gets the child_digest of this Reference.  # noqa: E501

        The digest of the child artifact  # noqa: E501

        :return: The child_digest of this Reference.  # noqa: E501
        :rtype: str
        """
        return self._child_digest

    @child_digest.setter
    def child_digest(self, child_digest):
        """Sets the child_digest of this Reference.

        The digest of the child artifact  # noqa: E501

        :param child_digest: The child_digest of this Reference.  # noqa: E501
        :type: str
        """

        self._child_digest = child_digest

    @property
    def platform(self):
        """Gets the platform of this Reference.  # noqa: E501


        :return: The platform of this Reference.  # noqa: E501
        :rtype: Platform
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this Reference.


        :param platform: The platform of this Reference.  # noqa: E501
        :type: Platform
        """

        self._platform = platform

    @property
    def annotations(self):
        """Gets the annotations of this Reference.  # noqa: E501


        :return: The annotations of this Reference.  # noqa: E501
        :rtype: Annotations
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Reference.


        :param annotations: The annotations of this Reference.  # noqa: E501
        :type: Annotations
        """

        self._annotations = annotations

    @property
    def urls(self):
        """Gets the urls of this Reference.  # noqa: E501

        The download URLs  # noqa: E501

        :return: The urls of this Reference.  # noqa: E501
        :rtype: list[str]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this Reference.

        The download URLs  # noqa: E501

        :param urls: The urls of this Reference.  # noqa: E501
        :type: list[str]
        """

        self._urls = urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Reference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Reference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Reference):
            return True

        return self.to_dict() != other.to_dict()
